import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import '../utils/image_utils.dart';

class StateLayout extends StatefulWidget {
  const StateLayout({Key? key, required this.type, this.hintText})
      : super(key: key);

  final StateType type;
  final String? hintText;
  @override
  State<StateLayout> createState() => _StateLayoutState();
}

class _StateLayoutState extends State<StateLayout> {
  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: SizedBox(
        height: MediaQuery.of(context).size.height - 30.0,
        child: widget.type == StateType.loading
            ? _loadingWidget()
            : _otherWidget(),
      ),
    );
  }

  Widget _loadingWidget() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.center,
      children: const [
        CupertinoActivityIndicator(radius: 16.0),
        SizedBox(
          width: double.infinity,
          height: 16.0,
        ),
        SizedBox(
          height: 50,
        ),
      ],
    );
  }

  Widget _otherWidget() {
    switch (widget.type) {
      case StateType.network:
        return _buildNormalView('icon_no_wifi', '无网络连接');
      case StateType.loading:
        return Container();
      case StateType.empty:
        return _buildNormalView('icon_empty', widget.hintText ?? '暂无数据');
      case StateType.error:
        return _buildNormalView('icon_list_failure', '请求失败，请重试');
      case StateType.success:
        return Container();
    }
  }

  Widget _buildNormalView(String img, String hintText) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        Opacity(
            opacity: 1,
            child: Container(
              height: 120.0,
              width: 120.0,
              decoration: BoxDecoration(
                image: DecorationImage(
                  image: ImageUtils.getAssetImage(img),
                ),
              ),
            )),
        const SizedBox(
          width: double.infinity,
          height: 16.0,
        ),
        Text(
          hintText,
          style: const TextStyle(fontSize: 14, color: Colors.grey),
        ),
        const SizedBox(
          height: 50,
        ),
      ],
    );
  }
}

enum StateType {
  /// 无网络
  network,

  /// 加载中
  loading,

  /// 空
  empty,

  ///异常
  error,

  ///成功
  success
}
